<?php
$TRANSLATIONS = array(
"Email sent" => "Message de e-posta inviate",
"Language changed" => "Linguage cambiate",
"Invalid request" => "Requesta invalide",
"Error" => "Error",
"Update" => "Actualisar",
"Very weak password" => "Contrasigno multo debile",
"Weak password" => "Contrasigno debile",
"So-so password" => "Contrasigno passabile",
"Good password" => "Contrasigno bon",
"Strong password" => "Contrasigno forte",
"Groups" => "Gruppos",
"Delete" => "Deler",
"never" => "nunquam",
"__language_name__" => "Interlingua",
"Security Warning" => "Aviso de securitate",
"Log" => "Registro",
"More" => "Plus",
"Add your App" => "Adder tu application",
"Select an App" => "Selectionar un app",
"Get the apps to sync your files" => "Obtene le apps (applicationes) pro synchronizar tu files",
"Password" => "Contrasigno",
"Unable to change your password" => "Non pote cambiar tu contrasigno",
"Current password" => "Contrasigno currente",
"New password" => "Nove contrasigno",
"Change password" => "Cambiar contrasigno",
"Email" => "E-posta",
"Your email address" => "Tu adresse de e-posta",
"Profile picture" => "Imagine de profilo",
"Cancel" => "Cancellar",
"Language" => "Linguage",
"Help translate" => "Adjuta a traducer",
"Create" => "Crear",
"Group" => "Gruppo",
"Default Quota" => "Quota predeterminate",
"Other" => "Altere",
"Username" => "Nomine de usator",
"Quota" => "Quota"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
